#include <iostream>
#include <fstream>
#include <sstream>
#include <iomanip>

#include <algorithm>
#include <cmath>

#include <chrono>
#include <random>

#include <unordered_map>
#include <unordered_set>
#include <functional>
#include <vector>
#include <string>
#include <array>
#include <tuple>
#include <deque>
#include <queue>
#include <stack>
#include <list>
#include <set>
#include <map>

using namespace std;
using namespace chrono;

using ll = long long;
using ull = unsigned long long;
using ld = long double;

constexpr ll INF = 1e15;
constexpr ld EPS = 1e-10L;

mt19937 rnd(0);


//
//struct Node {
//    ll a, b;
//    ll ind;
//};
//
//bool cmp(Node a, Node b) {
//    if (a.a * b.b > a.b * b.a) {
//        return true;
//    }
//    return false;
//}

struct pt {
    ll x = 0, y = 0;
    ll ind = -1;

    pt() = default;

    pt(ll x, ll y) : x(x), y(y) {}
    pt(ll x, ll y, ll ind) : x(x), y(y), ind(ind) {}
};

pt operator-(pt A, pt B) {
    return pt(A.x - B.x, A.y - B.y);
}

ll len(pt A) {
    return A.x * A.x + A.y * A.y;
}

ll len(pt a, pt b) {
    return len(a - b);
}

ll dot(pt A, pt B) {
    return A.x * B.x + A.y * B.y;
}

ll cross(pt A, pt B) {
    return A.x * B.y - A.y * B.x;
}

struct seg {
    pt a, b;
    seg(pt a, pt b) : a(a), b(b) {}
};

ll len(seg s) {
    return len(s.a, s.b);
}

bool bounding_box(ll l1, ll r1, ll l2, ll r2) {
    if (l1 > r1) swap(l1, r1);
    if (l2 > r2) swap(l2, r2);
    if (l1 > l2) {
        swap(l1, l2);
        swap(r1, r2);
    }
    return r1 >= l2;
}

bool intersect(seg s1, seg s2) {
    return ((cross(s2.a - s2.b, s1.a - s2.b) * cross(s2.a - s2.b, s1.b - s2.b) <= 0) && (cross(s1.a - s1.b, s2.a - s1.b) * cross(s1.a - s1.b, s2.b - s1.b) <= 0) && bounding_box(s1.a.x, s1.b.x, s2.a.x, s2.b.x) && bounding_box(s1.a.y, s1.b.y, s2.a.y, s2.b.y));
}

bool is_per_seg(seg s, pt c) {
    return dot(s.a - s.b, c - s.b) * dot(s.b - s.a, c - s.a) >= 0;
}

long double perp(seg s, pt c) {
    return abs(dot(pt((s.a - s.b).y, -(s.a - s.b).x), c - s.b)) / len(s);
}

long double dist(seg s, pt c) {
    if (is_per_seg(s, c))
        return perp(s, c);
    else
        return min(len(c, s.a), len(c, s.b));
}

long double dist(seg s1, seg s2) {
    if (intersect(s1, s2))
        return 0;
    else
        return min(min(dist(s1, s2.a), dist(s1, s2.b)), min(dist(s2, s1.a), dist(s2, s1.b)));
}


bool check(seg A, seg B, seg l) {
    return dist(A, B) <= len(l) + EPS;
}

bool operator<(const pt& a, const pt& b) {
    if ((a.y < 0 || (a.y == 0 && a.x < 0)) && (b.y > 0 || (b.y == 0 && b.x > 0)))
        return true;
    if ((a.y > 0 || (a.y == 0 && a.x > 0)) && (b.y < 0 || (b.y == 0 && b.x < 0)))
        return false;

    auto buf = cross(a, b);
    if (buf > 0)
        return true;
    if (buf < 0)
        return false;

    return len(a) < len(b);
}

bool operator==(const pt& a, const pt& b) {
    return a.x == b.x && a.y == b.y;
}

vector<ll> convex(const vector<pt>& a) {
    ll mn = 0;
    for (ll i = 1; i < a.size(); ++i) {
        if (a[i].x < a[mn].x)
            mn = i;
        if (a[i].x == a[mn].x && a[i].y < a[mn].y)
            mn = i;
    }

    vector<ll> b(a.size());
    for (ll i = 0; i < b.size(); ++i) b[i] = i;

    swap(b[0], b[mn]);
    sort(b.begin() + 1, b.end(), [&](ll x, ll y) {return (a[x] - a[mn]) < (a[y] - a[mn]); });

    vector<ll> res;
    for (auto& t : b) {
        while (res.size() >= 2) {
            if (a[t] == a[res.back()]) {
                res.pop_back();
                continue;
            }

            auto q = a[res.back()] - a[res.size() - 2];
            auto w = a[t] - a[res.back()];

            if (cross(q, w) < 0) {
                res.pop_back();
            }
            else {
                break;
            }
        }
        res.push_back(t);
    }

    return res;
}

int main() {
    ios_base::sync_with_stdio(false);
    cout.tie(nullptr);
    cin.tie(nullptr);


    ll n;
    cin >> n;
    vector<pt> a(n);
    
    for (ll i = 0; i < n; ++i) {
        cin >> a[i].x >> a[i].y;
        a[i].ind = i;
    }

    ll mn = 0;
    for (ll i = 1; i < a.size(); ++i) {
        if (a[i].x < a[mn].x)
            mn = i;
        if (a[i].x == a[mn].x && a[i].y < a[mn].y)
            mn = i;
    }

    cout << a[mn].ind + 1 << ' ';
    
    for (ll kkk = 0; kkk < n; kkk++) {
        auto buf = convex(a);

        vector<ll> k;
        for (ll i = 1; i < buf.size(); ++i) {
            cout << a[buf[i]].ind + 1 << ' ';
            k.push_back(a[buf[i]].ind);
        }
        sort(k.begin(), k.end());

        vector<pt> b;
        for (auto& t : a) {
            if (!binary_search(k.begin(), k.end(), t.ind))
                b.push_back(t);
        }
        a = b;
    }
}