#include <bits/stdc++.h>

using namespace std;

typedef long double ld;
typedef long long ll;

#define Vector Point
#define int long long

const ld eps = 1e-12;

struct Point {
    ll x, y;

    Point(ll _x, ll _y) : x(_x), y(_y) {}

    Point operator-(Point oth) const {
        return {x - oth.x, y - oth.y};
    }

    Point operator+(Point oth) const {
        return {x + oth.x, y + oth.y};
    }

    bool operator==(Point oth) const {
        return abs(x - oth.x) == 0 && abs(y - oth.y) == 0;
    }

    Point operator*(ll c) const {
        return {x * c, y * c};
    }

    ld operator*(Point oth) const {
        return x * oth.x + y * oth.y;
    }

    ld operator^(Point oth) const {
        return x * oth.y - y * oth.x;
    }

    Point operator*=(ll c) {
        x *= c;y *= c;
        return *this;
    }

    Point operator/=(ll c) {
        x /= c;y /= c;
        return *this;
    }
};

struct Cut {
    Point start, end;
};

ld getLen(Vector p) {
    return sqrt(p.x*p.x + p.y * p.y);
}

ld getDistance(Point a, Point b) {
    return getLen(b - a);
}

bool intersec(Cut a, Cut b) {
    return
            ((a.end - a.start)^(b.start - a.start)) * ((a.end - a.start)^(b.end - a.start)) <= 0 &&
            ((a.start - a.end)^(b.start - a.end)) * ((a.start - a.end)^(b.end - a.end)) <= 0 &&
            ((b.end - b.start)^(a.start - b.start)) * ((b.end - b.start)^(a.end - b.start)) <= 0 &&
            ((b.start - b.end)^(a.start - b.end)) * ((b.start - b.end)^(a.end - b.end)) <= 0;
}

ld getDistance(Point a, Cut b) {
    if((a - b.start)*(b.end - b.start) <= 0) {
        return getDistance(a, b.start);
    }

    if((a - b.end) * (b.start - b.end) <= 0) {
        return getDistance(a, b.end);
    }

    ld osn = getLen(b.end - b.start);
    ll S = abs((b.start - a)^(b.end - a));
    return S / osn;
}

ld getDistance(Cut a, Cut b) {
    if(intersec(a, b)) {
        return 0.0;
    } else {
        ld answer = getDistance(a.start, b);
        answer = min(answer, getDistance(a.end, b));
        answer = min(answer, getDistance(b.end, a));
        answer = min(answer, getDistance(b.start, a));
        return answer;
    }
}


ld rd() {
    ld x; cin >> x;
    return x;
}

ll rl() {
    ll x; cin >> x;
    return x;
}

void solve() {
    int n; cin >> n;
    vector<Cut> cuts(n, {{0, 0}, {0, 0}});
    for (int i = 0; i < n; i++) {
        cuts[i] = {{rd(), rd()}, {rd(), rd()}};
    }

    int answer = 0;
    set<int> st;
    for (int first = 0; first < n; first++) {
        for (int second = 0; second < n; second++) {
            for (int third = 0; third < n; third++) {
                if (first == second || second == third || third == first)
                    continue;
                if (getLen(cuts[first].end - cuts[first].start) - getDistance(cuts[second], cuts[third]) >= -eps) {
                    int a = min(first, min(second, third));
                    int b = max(first, max(second, third));
                    int c = first + second + third - a - b;
                    st.insert(a + 1 + 101 * (b + 1) + 100001 * (c + 1));
                }
            }
        }
    }

    cout << st.size();
}

signed main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    int T = 1;
    while (T--)
        solve();
    return 0;
}